@@ -46,6 +46,8 @@ def create_tests_here(tests: Iterable[TestyRunner], module=None):
         module = inspect.getmodule(frm[0])
     module = module.__dict__
     for runner in tests:
+        if runner.case_name in module:
+            raise KeyError(f"{runner.case_name} already in module.")
         test_class_dict = dict()
         test_class_dict["setup_fct"] = lambda self: _setup(self, runner.function_to_run,
                                                            [t[0] for t in runner.check_functions])
@@ -55,5 +57,6 @@ def create_tests_here(tests: Iterable[TestyRunner], module=None):
             f = partial(_compare, comparer=comparer, value=value, name=name)
             # test_class_dict["test_"+name] = f #ToDo: figure out why this does not work
             test_class_dict["test_" + name] = f1
+
         cls = type(runner.case_name, (unittest.TestCase,), test_class_dict)
         module[runner.case_name] = cls
